@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild::Repository::Local;
 use strict;
 use warnings;
 
-our $VERSION = '0.037_02';
+our $VERSION = '0.001';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -50,7 +50,7 @@ sub get_file  {
 
   copy $full_file, $CWD;
 
-  return $file;
+  return 1;
 }
 
 1;
